@@ -9,7 +9,7 @@
 # If publications result from research using this SOFTWARE, we ask that the Ontario Institute for Cancer Research be acknowledged and/or
 # credit be given to OICR scientists, as scientifically appropriate.
 
-test.region.similarity <- function (x, y, n = 1e3, stratify.by.chr = FALSE, species = "human", build = "hg19", mask.gaps = FALSE, mask.repeats = FALSE, gaps.file = NULL, repeats.file = NULL, check.zero.based = TRUE, check.chr = TRUE, check.valid = TRUE, verbose = TRUE) {
+test.region.similarity <- function(x, y, n = 1e3, stratify.by.chr = FALSE, species = "human", build = "hg19", mask.gaps = FALSE, mask.repeats = FALSE, gaps.file = NULL, repeats.file = NULL, check.zero.based = TRUE, check.chr = TRUE, check.valid = TRUE, verbose = TRUE) {
 
 #	is.valid.region(x, check.zero.based = check.zero.based, check.chr = check.chr, verbose = verbose);
 #	is.valid.region(y, check.zero.based = check.zero.based, check.chr = check.chr, verbose = verbose);
@@ -22,22 +22,19 @@ test.region.similarity <- function (x, y, n = 1e3, stratify.by.chr = FALSE, spec
 	
 	if (nrow(reldist.orig)!=0) {
 		reldist.orig.median           <- tail(reldist.orig[cumsum(reldist.orig$count/sum(reldist.orig$count))  <= 0.5,"reldist"], 1);
-		}
-	else {
+		} else {
 		reldist.orig.median <- 0.25;
 		}
 
 	if (0 %in% reldist.orig$reldist) {
 		reldist.orig.fraction.zero    <- reldist.orig[reldist.orig$reldist == 0,"fraction"]; # the fraction at reldist 0.  if uniform all 50 fractions = 0.02
-		}
-	else {
+		} else {
 		reldist.orig.fraction.zero <- 0;
 		}
 		
 	if (0.5 %in% reldist.orig$reldist) {
 		reldist.orig.fraction.fifty    <- reldist.orig[reldist.orig$reldist == 50,"fraction"]; # the fraction at reldist 0.  if uniform all 50 fractions = 0.02
-		}
-	else {
+		} else {
 		reldist.orig.fraction.fifty <- 0;
 		}
 	
@@ -55,8 +52,7 @@ test.region.similarity <- function (x, y, n = 1e3, stratify.by.chr = FALSE, spec
 
 		if (1 == n.batches) {
 			batch.size <- n;
-			}
-		else if  (i == n.batches) {
+			} else if  (i == n.batches) {
 			batch.size <- batch.size %% n;
 			}
 
@@ -65,7 +61,32 @@ test.region.similarity <- function (x, y, n = 1e3, stratify.by.chr = FALSE, spec
 
 		# send batches of permutations
 
-		perm.results <- mclapply(list(1:n.batches), iterate.perm, x.region = x, y.region = y, batch.size = batch.size, jaccard.orig = jaccard.orig, reldist.orig.median = reldist.orig.median, reldist.orig.fraction.zero = reldist.orig.fraction.zero, reldist.orig.fraction.fifty = reldist.orig.fraction.fifty, stratify.by.chr = stratify.by.chr, species = species, build = build, mask.gaps = mask.gaps, mask.repeats = mask.repeats, gaps.file = gaps.file, repeats.file = repeats.file);
+		## FIX PLEASE
+		perm.results <- mclapply(
+			list(1:n.batches),
+			iterate.perm,
+			x.region = x,
+			y.region = y,
+			batch.size = batch.size,
+			jaccard.orig = jaccard.orig,
+			reldist.orig.median = reldist.orig.median,
+			reldist.orig.fraction.zero = reldist.orig.fraction.zero,
+			reldist.orig.fraction.fifty = reldist.orig.fraction.fifty,
+			stratify.by.chr = stratify.by.chr,
+			species = species,
+			build = build,
+			mask.gaps = mask.gaps,
+			mask.repeats = mask.repeats, 
+			gaps.file = gaps.file,
+			repeats.file = repeats.file
+			);
+
+		## ERROR
+		# Segmentation fault
+		# Error in bedr(engine = "bedtools", input = list(a = x, b = y), method = "reldist",  :
+		# In addition: Warning message:
+		# In system(command, wait = TRUE, intern = intern, ignore.stdout = FALSE,  :
+		#   running command 'bedtools reldist -a /tmp/RtmpxT5wu9/a_1fb74ae24ca7.bed -b /tmp/RtmpxT5wu9/b_1fb744111522.bed ' had status 139
   
 #		if (i == 100 ) {
 #			if (jaccard.perm.gt > 20 && reldist.perm.median.lt > 20) break;
@@ -99,6 +120,7 @@ iterate.perm <- function(x, x.region, y.region, batch.size, jaccard.orig, reldis
 	for (i in 1:batch.size) {
 		x.perm       <- permute.region(x.region, stratify.by.chr = stratify.by.chr, species = species, build = build, mask.gaps = mask.gaps, mask.repeats = mask.repeats, gaps.file = gaps.file, repeats.file = repeats.file, is.checked = TRUE, sort.output = TRUE);
 		jaccard.perm <- jaccard(x.perm, y.region, check.chr = FALSE, check.valid = FALSE, check.sort = FALSE, check.merge = FALSE, verbose = FALSE)[1,3];
+		## CAUSING SEGEMENTATION FAULT
 		reldist.perm <- reldist(x.perm, y.region, check.chr = FALSE, check.valid = FALSE, check.sort = FALSE, check.merge = FALSE, verbose = FALSE);
 
 		# if reldist fails
